aboutsummaryrefslogtreecommitdiffstats
path: root/config
diff options
context:
space:
mode:
Diffstat (limited to 'config')
-rw-r--r--config/aerc.conf6
-rw-r--r--config/general.go4
2 files changed, 5 insertions, 5 deletions
diff --git a/config/aerc.conf b/config/aerc.conf
index 8f3fd097..ecae5b90 100644
--- a/config/aerc.conf
+++ b/config/aerc.conf
@@ -31,9 +31,9 @@
#log-file=
# Only log messages above the specified level to log-file. Supported levels
-# are: debug, info, warn and error. When redirecting aerc's output to a file
-# using > shell redirection, this setting is ignored and the log level is
-# forced to debug.
+# are: trace, debug, info, warn and error. When redirecting aerc's output to
+# a file using > shell redirection, this setting is ignored and the log level
+# is forced to trace.
#
# Default: info
#log-level=info
diff --git a/config/general.go b/config/general.go
index b06eddde..2c09a14e 100644
--- a/config/general.go
+++ b/config/general.go
@@ -51,8 +51,8 @@ func (config *AercConfig) parseGeneral(file *ini.File) error {
end:
if !isatty.IsTerminal(os.Stdout.Fd()) {
logFile = os.Stdout
- // redirected to file, force DEBUG level
- config.General.LogLevel = log.DEBUG
+ // redirected to file, force TRACE level
+ config.General.LogLevel = log.TRACE
} else if config.General.LogFile != "" {
path, err := homedir.Expand(config.General.LogFile)
if err != nil {